pub type BlockSize = GenericBlockSize<MaskShiftSpec>;Expand description
A GenericBlockSize configured with a block size stored as a MaskShiftSpec.
Aliased Type
pub struct BlockSize(/* private fields */);Implementations
Sourceimpl BlockSize
impl BlockSize
pub const SIZE_512B: Self
pub const SIZE_1KIB: Self
pub const SIZE_2KIB: Self
pub const SIZE_4KIB: Self
pub const SIZE_8KIB: Self
pub const SIZE_16KIB: Self
pub const SIZE_32KIB: Self
pub const SIZE_64KIB: Self
pub const SIZE_128KIB: Self
pub const SIZE_256KIB: Self
pub const SIZE_512KIB: Self
pub const SIZE_1MIB: Self
Sourcepub const fn new(block_size: u32) -> Option<Self>
pub const fn new(block_size: u32) -> Option<Self>
Constructs a BlockSize from a u32 byte count if it is a power of 2 and not equal to 0.