pub struct GenericBlockSize<T: BlockSizeSpec>(/* private fields */);Expand description
Represents a block size that is a power of 2, parameterized by a BlockSizeSpec.
Provides zero-cost bitwise operations for alignments, conversions, and arithmetic with integers.
Implementations
Sourceimpl<T: BlockSizeSpec> GenericBlockSize<T>
impl<T: BlockSizeSpec> GenericBlockSize<T>
pub fn from_spec(spec: T) -> Self
Sourcepub fn is_aligned(self, value: impl IsAligned<T>) -> bool
pub fn is_aligned(self, value: impl IsAligned<T>) -> bool
Returns true if value is aligned to this block size.
Sourcepub fn align_up(self, bytes: u64) -> Option<u64>
pub fn align_up(self, bytes: u64) -> Option<u64>
Aligns bytes up to the nearest block boundary, returning None on overflow.
Sourcepub fn align_down(self, bytes: u64) -> u64
pub fn align_down(self, bytes: u64) -> u64
Aligns bytes down to the nearest block boundary.
Sourcepub fn align_up_to_blocks(self, bytes: u64) -> u64
pub fn align_up_to_blocks(self, bytes: u64) -> u64
Aligns bytes up to the nearest block boundary and returns the total number of blocks.
Sourceimpl GenericBlockSize<MaskShiftSpec>
impl GenericBlockSize<MaskShiftSpec>
pub const SIZE_512B: Self
pub const SIZE_1KIB: Self
pub const SIZE_2KIB: Self
pub const SIZE_4KIB: Self
pub const SIZE_8KIB: Self
pub const SIZE_16KIB: Self
pub const SIZE_32KIB: Self
pub const SIZE_64KIB: Self
pub const SIZE_128KIB: Self
pub const SIZE_256KIB: Self
pub const SIZE_512KIB: Self
pub const SIZE_1MIB: Self
Sourcepub const fn new(block_size: u32) -> Option<Self>
pub const fn new(block_size: u32) -> Option<Self>
Constructs a BlockSize from a u32 byte count if it is a power of 2 and not equal to 0.