BlockSize

Type Alias BlockSize 

pub type BlockSize = GenericBlockSize<MaskShiftSpec>;
A GenericBlockSize configured with a block size stored as a MaskShiftSpec.

Aliased Type

pub struct BlockSize(/* private fields */);

Implementations

Source

impl BlockSize

pub const SIZE_512B: Self

pub const SIZE_1KIB: Self

pub const SIZE_2KIB: Self

pub const SIZE_4KIB: Self

pub const SIZE_8KIB: Self

pub const SIZE_16KIB: Self

pub const SIZE_32KIB: Self

pub const SIZE_64KIB: Self

pub const SIZE_128KIB: Self

pub const SIZE_256KIB: Self

pub const SIZE_512KIB: Self

pub const SIZE_1MIB: Self

pub const fn new(block_size: u32) -> Option<Self>

Constructs a BlockSize from a u32 byte count if it is a power of 2 and not equal to 0.

pub const fn from_u64(block_size: u64) -> Option<Self>

Constructs a BlockSize from a u64 if it is a power of 2, not equal to 0, and the mask fits in a u32. This is equivalent to Self::new but allows for constructing a 4GiB block size.

pub const fn size(self) -> u64

Returns the block size in bytes.

Equivalent to Self::get but can be called from a const context.